unit Select;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExtCtrls, StdCtrls, Buttons, Tabs, Ikona;

type
  TSelForm = class(TForm)
    TabSet: TTabSet;
    PanelSpeed: TPanel;
    ButtonExit: TSpeedButton;
    ButtonLeft: TSpeedButton;
    ButtonRight: TSpeedButton;
    Edit: TEdit;
    PanelStatus: TPanel;
    Image: TImage;
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure DispForm;
    procedure FormKeyPress(Sender: TObject; var Key: Char);
    procedure ButtonExitClick(Sender: TObject);
    procedure TabSetClick(Sender: TObject);
    procedure ButtonLeftClick(Sender: TObject);
    procedure ButtonRightClick(Sender: TObject);
    procedure EditKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure EditKeyPress(Sender: TObject; var Key: Char);
    procedure ImageMouseMove(Sender: TObject; Shift: TShiftState; X,
      Y: Integer);
    procedure ImageMouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure LoadResTxt;
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  SelForm: TSelForm;
  SelectTxt: string;

implementation

uses Main;

{$R *.DFM}

procedure TSelForm.FormCreate(Sender: TObject);
var Bitmap: TBitmap;
begin
  LoadResTxt;

{ pprava plochy k volb }
  Bitmap := TBitmap.Create;
  Bitmap.Width := IconXNum*IconWidth+IconXNum-1;
  Bitmap.Height := IconYNum*IconHeight+IconYNum-1;
  Image.Picture.Graphic := Bitmap;
  Image.Picture.Bitmap.Palette := MainForm.InitPal;

  SelForm.ButtonLeft.Glyph.Palette := MainForm.InitPal;
  SelForm.ButtonRight.Glyph.Palette := MainForm.InitPal;
  SelForm.ButtonExit.Glyph.Palette := MainForm.InitPal;
end;

procedure TSelForm.LoadResTxt;
begin
  SelectTxt := LoadResString(IDS_CAPTION+10);
  TabSet.Hint := LoadResString(IDS_SELECT+0);
  Edit.Hint := LoadResString(IDS_SELECT+1);
  ButtonLeft.Hint := LoadResString(IDS_SELECT+2);
  ButtonRight.Hint := LoadResString(IDS_SELECT+3);
  ButtonExit.Hint := LoadResString(IDS_SELECT+4);
end;

procedure TSelForm.FormShow(Sender: TObject);
var I: Integer;
begin
  if EditName = '' then EditName := 'BALTIK';
  Caption := EditName + SelectTxt;
  with TabSet do
  begin
    Tabs.Clear;
    for I := 0 to MaxBank-1 do
      if Assigned(SelBanks^[I]^.bnBitmap) then Tabs.Add(IntToStr(I));
    if Tabs.Count = 0 then Tabs.Add('0');
    if SelIndex > Tabs.Count-1 then SelIndex := Tabs.Count-1;
    TabIndex := SelIndex;
  end;
  Tag := -1;
  TabSetClick(Sender);
end;

procedure TSelForm.TabSetClick(Sender: TObject);
begin
  SelIndex := TabSet.TabIndex;
  Edit.Text := TabSet.Tabs[SelIndex];
  ActiveControl := PanelSpeed;
  DispForm;
end;

procedure TSelForm.DispForm;
var I,J: Integer;
    Cislo: Integer;
    Banka: TBitmap;
begin
  with Image.Canvas do
  begin
    Cislo := StrToInt(TabSet.Tabs[TabSet.TabIndex]);
    Banka := SelBanks^[Cislo]^.bnBitmap;
    Brush.Style := bsSolid;
    Brush.Color := clBlack;
    for I := 0 to IconXNum-1 do
      for J := 0 to IconYNum-1 do
        if Assigned(Banka) then
          CopyRect(
            Rect(I*IconWidth+I,J*IconHeight+J,
                 (I+1)*IconWidth+I,(J+1)*IconHeight+J),
            Banka.Canvas,
            Rect(I*IconWidth,J*IconHeight,
                 (I+1)*IconWidth,(J+1)*IconHeight))
        else
          FillRect(
            Rect(I*IconWidth+I,J*IconHeight+J,
                 (I+1)*IconWidth+I,(J+1)*IconHeight+J));

    Pen.Color := clWhite;
    Pen.Width := 1;
    Pen.Style := psSolid;
    Pen.Mode := pmCopy;

    for I := 1 to IconXNum-1 do
    begin
      MoveTo(I*IconWidth+I-1,0);
      LineTo(I*IconWidth+I-1,IconYNum*IconHeight+IconYNum);
    end;

    for J := 1 to IconYNum-1 do
    begin
      MoveTo(0,J*IconHeight+J-1);
      LineTo(IconXNum*IconWidth+IconXNum,J*IconHeight+J-1);
    end;
  end;
end;

procedure TSelForm.FormKeyPress(Sender: TObject; var Key: Char);
begin
  Case Key of
    #27:
         begin
           Key := #0;
           if ActiveControl = Edit then
           begin
             Edit.Text := TabSet.Tabs[TabSet.TabIndex];
             ActiveControl := PanelSpeed;
           end
           else
             Close;
         end;
    '0'..'9':
         if ActiveControl = PanelSpeed then
         begin
           ActiveControl := Edit;
           Edit.Text := Key;
           Edit.SelStart := 1;
         end;
  end;
end;

procedure TSelForm.ButtonExitClick(Sender: TObject);
begin
  Close;
end;

procedure TSelForm.ButtonLeftClick(Sender: TObject);
begin
  TabSet.SelectNext(False);
end;

procedure TSelForm.ButtonRightClick(Sender: TObject);
begin
  TabSet.SelectNext(True);
end;

procedure TSelForm.EditKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
var Cislo: Integer;
    I: Integer;
begin
  Case Key of
    VK_RETURN:
      begin
        with Edit do
        begin
          Cislo := StrToIntDef(Text,-1);
          if (Cislo < 0) or (Cislo >= MaxBank) then
            Edit.Text := TabSet.Tabs[TabSet.TabIndex]
          else
          begin
            Text := IntToStr(Cislo);
            with TabSet do
            begin
              if Tabs.IndexOf(Text) < 0 then
                for I := 0 to Tabs.Count-1 do
                  if StrToIntDef(Tabs[I],0) > Cislo then
                  begin
                    Tabs.Insert(I,Text);
                    Break;
                  end;
              if Tabs.IndexOf(Text) < 0 then Tabs.Add(Text);
              TabIndex := Tabs.IndexOf(Text);
            end; { with TabSetPic }
          end; { if Cislo }
        end;  { with EDIT }
        ActiveControl := PanelSpeed;
        MainForm.ShowHint(Sender);
      end; { VK_RETURN }
  end;  { CASE }
end;

procedure TSelForm.EditKeyPress(Sender: TObject; var Key: Char);
begin
  Case Key of
    #13: Key := #0;
  end;
end;

procedure TSelForm.ImageMouseMove(Sender: TObject; Shift: TShiftState; X,
  Y: Integer);
var Predmet: Longint;
begin
  Predmet := StrToInt(TabSet.Tabs[TabSet.TabIndex])* 1000
              + X div (IconWidth+1) + 1
              + (Y div (IconHeight+1))*IconXNum;

  with Image do
    if (X >= 0) and (X < IconXNum*(IconWidth+1)) and
       (Y >= 0) and (Y < IconYNum*(IconHeight+1)) then
    begin
      Hint := TextPredmet + IntToStr(Predmet);
      if SelBanks^[(Predmet-1) div 1000]^.bnPruchod[(Predmet-1) mod 1000] <> 1 then
        Hint := Hint + TextNepruch;
    end
    else
      Hint := '';
end;

procedure TSelForm.ImageMouseUp(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
var Bod: TPoint;
begin
  with Image do
    if (X >= 0) and (X < IconXNum*(IconWidth+1)) and
       (Y >= 0) and (Y < IconYNum*(IconHeight+1)) then
    begin
      SelForm.Tag := 1 + X div (IconWidth+1)
            + (Y div (IconHeight+1))*IconXNum
            + 1000*StrToInt(TabSet.Tabs[TabSet.TabIndex]);
      Bod.X := X;
      Bod.Y := Y;
      Bod := Image.ClientToScreen(Bod);
      IkonForm.Left := Bod.X - IkonForm.Width div 2;
      IkonForm.Top := Bod.Y - IkonForm.Height div 2;
      Close;
    end;
end;

end.
